@@ -1,12 +1,12 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "citar-embark" "1.4.0"
+(define-package "citar-embark" "20251027.1830"
   "Citar/Embark integration."
   '((emacs  "27.1")
     (embark "0.17")
     (citar  "0.9.7"))
-  :url "https://github.com/emacs-citar/citar-embark"
-  :commit "e21bf22b29d8ca40649517bb7dc503765f240282"
-  :revdesc "v1.4.0-0-ge21bf22b29d8"
+  :url "https://github.com/emacs-citar/citar"
+  :commit "a71ec7c3f02e8d4051fb608d9c4918de5a8ba4e6"
+  :revdesc "a71ec7c3f02e"
   :keywords '("bib" "extensions")
   :authors '(("Bruce D'Arcus" . "bdarcus@gmail.com"))
   :maintainers '(("Bruce D'Arcus" . "bdarcus@gmail.com")))
